@@ -1,16 +1,17 @@
-
 import warnings
 from typing import Callable, List, Optional, Union
 
 import mpmath
 import numpy as np
-import paramak
 import sympy as sp
-from paramak import RotateMixedShape, diff_between_angles
-from paramak.parametric_components.tokamak_plasma_plasmaboundaries import \
-    PlasmaBoundaries
 from scipy.interpolate import interp1d
 
+import paramak
+from paramak import RotateMixedShape, diff_between_angles
+from paramak.parametric_components.tokamak_plasma_plasmaboundaries import (
+    PlasmaBoundaries,
+)
+
 
 class BlanketFP(RotateMixedShape):
     """A blanket volume created from plasma parameters.
@@ -43,21 +44,24 @@ class BlanketFP(RotateMixedShape):
         num_points: number of points that will describe the shape.
     """
 
-    def __init__(self,
-                 thickness,
-                 start_angle: float,
-                 stop_angle: float,
-                 plasma: Optional[Union[paramak.Plasma,
-                                        paramak.PlasmaBoundaries,
-                                        paramak.PlasmaFromPoints]] = None,
-                 minor_radius: Optional[float] = 150.0,
-                 major_radius: Optional[float] = 450.0,
-                 triangularity: Optional[float] = 0.55,
-                 elongation: Optional[float] = 2.0,
-                 vertical_displacement: Optional[float] = 0.0,
-                 offset_from_plasma: Optional[float] = 0.0,
-                 num_points: Optional[int] = 50,
-                 **kwargs):
+    def __init__(
+        self,
+        thickness,
+        start_angle: float,
+        stop_angle: float,
+        plasma: Optional[
+            Union[paramak.Plasma, paramak.PlasmaBoundaries, paramak.PlasmaFromPoints]
+        ] = None,
+        minor_radius: Optional[float] = 150.0,
+        major_radius: Optional[float] = 450.0,
+        triangularity: Optional[float] = 0.55,
+        elongation: Optional[float] = 2.0,
+        vertical_displacement: Optional[float] = 0.0,
+        offset_from_plasma: Union[float, list] = 0.0,
+        num_points: Optional[int] = 50,
+        allow_overlapping_shape=False,
+        **kwargs
+    ):
 
         super().__init__(**kwargs)
 
@@ -67,6 +71,7 @@ class BlanketFP(RotateMixedShape):
         self.stop_angle = stop_angle
         self.plasma = plasma
         self.vertical_displacement = vertical_displacement
+        self.allow_overlapping_shape = allow_overlapping_shape
         if plasma is None:
             self.minor_radius = minor_radius
             self.major_radius = major_radius
@@ -79,7 +84,6 @@ class BlanketFP(RotateMixedShape):
             self.elongation = plasma.elongation
         self.offset_from_plasma = offset_from_plasma
         self.num_points = num_points
-        self.physical_groups = None
 
     @property
     def start_angle(self):
@@ -97,15 +101,6 @@ class BlanketFP(RotateMixedShape):
     def stop_angle(self, value):
         self._stop_angle = value
 
-    @property
-    def physical_groups(self):
-        self.create_physical_groups()
-        return self._physical_groups
-
-    @physical_groups.setter
-    def physical_groups(self, physical_groups):
-        self._physical_groups = physical_groups
-
     @property
     def minor_radius(self):
         return self._minor_radius
@@ -147,23 +142,25 @@ class BlanketFP(RotateMixedShape):
         # if the attribute is a list, create a interpolated object of the
         # values
         if isinstance(attribute, (tuple, list)):
-            if isinstance(attribute[0], (tuple, list)) and \
-                isinstance(attribute[1], (tuple, list)) and \
-                    len(attribute) == 2:
+            if (
+                isinstance(attribute[0], (tuple, list))
+                and isinstance(attribute[1], (tuple, list))
+                and len(attribute) == 2
+            ):
                 # attribute is a list of 2 lists
                 if len(attribute[0]) != len(attribute[1]):
-                    raise ValueError('The length of angles list must equal \
-                     the length of values list')
+                    raise ValueError(
+                        "The length of angles list must equal \
+                     the length of values list"
+                    )
                 list_of_angles = np.array(attribute[0])
                 offset_values = attribute[1]
             else:
                 # no list of angles is given
                 offset_values = attribute
                 list_of_angles = np.linspace(
-                    self.start_angle,
-                    self.stop_angle,
-                    len(offset_values),
-                    endpoint=True)
+                    self.start_angle, self.stop_angle, len(offset_values), endpoint=True
+                )
             interpolated_values = interp1d(list_of_angles, offset_values)
 
         def fun(theta):
@@ -173,6 +170,7 @@ class BlanketFP(RotateMixedShape):
                 return interpolated_values(theta)
             else:
                 return attribute
+
         return fun
 
     def find_points(self, angles=None):
@@ -206,9 +204,11 @@ class BlanketFP(RotateMixedShape):
 
         # assemble
         points = inner_points + outer_points
-        if self._overlapping_shape:
-            msg = ("BlanketFP: Some points with negative R coordinate have "
-                   "been ignored.")
+        if self._overlapping_shape and self.allow_overlapping_shape is False:
+            msg = (
+                "BlanketFP: Some points with negative R coordinate have "
+                "been ignored."
+            )
             warnings.warn(msg)
 
         self.points = points
@@ -253,74 +253,11 @@ class BlanketFP(RotateMixedShape):
             val_R_outer = self.distribution(theta)[0] + offset(theta) * nx
             val_Z_outer = self.distribution(theta)[1] + offset(theta) * ny
             if float(val_R_outer) > 0:
-                points.append(
-                    [float(val_R_outer), float(val_Z_outer), "spline"])
+                points.append([float(val_R_outer), float(val_Z_outer), "spline"])
             else:
                 self._overlapping_shape = True
         return points
 
-    def create_physical_groups(self):
-        """Creates the physical groups for STP files
-
-        Returns:
-            list: list of dicts containing the physical groups
-        """
-
-        groups = []
-        number_of_volumes = 1  # only one volume
-        number_of_surfaces = 2  # inner and outer
-
-        surface_names = ["inner", "outer"]
-        volumes_names = ["inside"]
-
-        # add two cut sections if they exist
-        if self.rotation_angle != 360:
-            number_of_surfaces += 2
-            surface_names += ["left_section", "right_section"]
-            full_rotation = False
-        else:
-            full_rotation = True
-
-        # add two surfaces between blanket and div if they exist
-        if diff_between_angles(self.start_angle, self.stop_angle) != 0:
-            number_of_surfaces += 2
-            surface_names += ["inner_section", "outer_section"]
-            stop_equals_start = False
-        else:
-            stop_equals_start = True
-
-        # rearrange order
-        new_order = [i for i in range(len(surface_names))]
-        if full_rotation:
-            if not stop_equals_start:
-                # from ["inner", "outer", "inner_section", "outer_section"]
-
-                # to ["inner", "inner_section", "outer", "outer_section"]
-                new_order = [0, 2, 1, 3]
-        else:
-            if stop_equals_start:
-                print(
-                    "Warning: If start_angle = stop_angle surfaces will not\
-                     be handled correctly"
-                )
-                new_order = [0, 1, 2, 3]
-            else:
-                # from ['inner', 'outer', 'left_section', 'right_section',
-                #           'inner_section', 'outer_section']
-
-                # to ["inner", "inner_section", "outer", "outer_section",
-                #         "left_section", "right_section"]
-                new_order = [0, 4, 1, 5, 2, 3]
-        surface_names = [surface_names[i] for i in new_order]
-
-        for i in range(1, number_of_volumes + 1):
-            group = {"dim": 3, "id": i, "name": volumes_names[i - 1]}
-            groups.append(group)
-        for i in range(1, number_of_surfaces + 1):
-            group = {"dim": 2, "id": i, "name": surface_names[i - 1]}
-            groups.append(group)
-        self.physical_groups = groups
-
     def distribution(self, theta, pkg=np):
         """Plasma distribution theta in degrees
 
