@@ -1,5 +1,5 @@
+from typing import Optional, Union, Tuple
 
-from typing import Optional, Tuple
 from paramak import RotateMixedShape
 
 
@@ -22,15 +22,11 @@ class CenterColumnShieldCircular(RotateMixedShape):
         inner_radius: float,
         mid_radius: float,
         outer_radius: float,
-        color: Optional[Tuple[float, float, float,
-                              Optional[float]]] = (0., 0.333, 0.),
+        color: Tuple[float, float, float, Optional[float]] = (0.0, 0.333, 0.0),
         **kwargs
     ) -> None:
 
-        super().__init__(
-            color=color,
-            **kwargs
-        )
+        super().__init__(color=color, **kwargs)
 
         self.height = height
         self.inner_radius = inner_radius
@@ -79,7 +75,7 @@ class CenterColumnShieldCircular(RotateMixedShape):
             (self.outer_radius, self.height / 2, "circle"),
             (self.mid_radius, 0, "circle"),
             (self.outer_radius, -self.height / 2, "straight"),
-            (self.inner_radius, -self.height / 2, "straight")
+            (self.inner_radius, -self.height / 2, "straight"),
         ]
 
         self.points = points
