@@ -1,5 +1,5 @@
-
 from typing import Optional, Tuple
+
 from paramak import RotateStraightShape
 
 
@@ -18,14 +18,11 @@ class PoloidalFieldCoil(RotateStraightShape):
         height: float,
         width: float,
         center_point: Tuple[float, float],
-        name: Optional[str] = "pf_coil",
+        name: str = "pf_coil",
         **kwargs
     ) -> None:
 
-        super().__init__(
-            name=name,
-            **kwargs
-        )
+        super().__init__(name=name, **kwargs)
 
         self.center_point = center_point
         self.height = height
@@ -75,7 +72,7 @@ class PoloidalFieldCoil(RotateStraightShape):
             (
                 self.center_point[0] - self.width / 2.0,
                 self.center_point[1] + self.height / 2.0,
-            )
+            ),
         ]
 
         self.points = points
