@@ -1,7 +1,7 @@
-
 from typing import Optional, Tuple
 
 import cadquery as cq
+
 from paramak import PoloidalFieldCoilSet, RotateStraightShape
 
 
@@ -23,15 +23,11 @@ class PoloidalFieldCoilCaseSetFC(RotateStraightShape):
         pf_coils,
         casing_thicknesses,
         name="pf_coil_case_set_fc",
-        color: Optional[Tuple[int, int, int]] = (1., 1., 0.498),
+        color: Tuple[float, float, float, Optional[float]] = (1.0, 1.0, 0.498),
         **kwargs
     ):
 
-        super().__init__(
-            name=name,
-            color=color,
-            **kwargs
-        )
+        super().__init__(name=name, color=color, **kwargs)
 
         self.casing_thicknesses = casing_thicknesses
         self.pf_coils = pf_coils
@@ -50,11 +46,13 @@ class PoloidalFieldCoilCaseSetFC(RotateStraightShape):
         if isinstance(value, list):
             if not all(isinstance(x, (int, float)) for x in value):
                 raise ValueError(
-                    "Every entry in Casing_thicknesses must be a float or int")
+                    "Every entry in Casing_thicknesses must be a float or int"
+                )
         else:
             if not isinstance(value, (float, int)):
                 raise ValueError(
-                    "Casing_thicknesses must be a list of numbers or a number")
+                    "Casing_thicknesses must be a list of numbers or a number"
+                )
         self._casing_thicknesses = value
 
     @property
@@ -64,9 +62,11 @@ class PoloidalFieldCoilCaseSetFC(RotateStraightShape):
     @pf_coils.setter
     def pf_coils(self, value):
         if not isinstance(value, (list, PoloidalFieldCoilSet)):
-            msg = ('PoloidalFieldCoilCaseSetFC.pf_coils must be either a list '
-                   'paramak.PoloidalFieldCoil or a '
-                   'paramak.PoloidalFieldCoilSet object')
+            msg = (
+                "PoloidalFieldCoilCaseSetFC.pf_coils must be either a list "
+                "paramak.PoloidalFieldCoil or a "
+                "paramak.PoloidalFieldCoilSet object"
+            )
             raise ValueError(msg)
         self._pf_coils = value
 
@@ -77,8 +77,7 @@ class PoloidalFieldCoilCaseSetFC(RotateStraightShape):
         if isinstance(self.pf_coils, list):
             self.heights = [entry.height for entry in self.pf_coils]
             self.widths = [entry.width for entry in self.pf_coils]
-            self.center_points = [
-                entry.center_point for entry in self.pf_coils]
+            self.center_points = [entry.center_point for entry in self.pf_coils]
 
             num_of_coils = len(self.pf_coils)
 
@@ -96,7 +95,8 @@ class PoloidalFieldCoilCaseSetFC(RotateStraightShape):
                     "casing_thicknesses=",
                     self.casing_thicknesses,
                     "num_of_coils=",
-                    num_of_coils)
+                    num_of_coils,
+                )
             casing_thicknesses_list = self.casing_thicknesses
         else:
             casing_thicknesses_list = [self.casing_thicknesses] * num_of_coils
@@ -104,8 +104,8 @@ class PoloidalFieldCoilCaseSetFC(RotateStraightShape):
         all_points = []
 
         for height, width, center_point, casing_thickness in zip(
-                self.heights, self.widths,
-                self.center_points, casing_thicknesses_list):
+            self.heights, self.widths, self.center_points, casing_thicknesses_list
+        ):
 
             if casing_thickness != 0:
 
@@ -149,7 +149,7 @@ class PoloidalFieldCoilCaseSetFC(RotateStraightShape):
                     (
                         center_point[0] + (casing_thickness + width / 2.0),
                         center_point[1] + (casing_thickness + height / 2.0),
-                    )
+                    ),
                 ]
 
         self.points = all_points
@@ -167,16 +167,31 @@ class PoloidalFieldCoilCaseSetFC(RotateStraightShape):
         pf_coils_set = []
         wires = []
         for p1, p2, p3, p4, p5, p6, p7, p8, p9, p10 in zip(
-                iter_points, iter_points, iter_points, iter_points,
-                iter_points, iter_points, iter_points, iter_points,
-                iter_points, iter_points,
+            iter_points,
+            iter_points,
+            iter_points,
+            iter_points,
+            iter_points,
+            iter_points,
+            iter_points,
+            iter_points,
+            iter_points,
+            iter_points,
         ):
 
-            solid = (
-                cq.Workplane(self.workplane)
-                .polyline(
-                    [p1[:2], p2[:2], p3[:2], p4[:2], p5[:2], p6[:2],
-                     p7[:2], p8[:2], p9[:2], p10[:2]])
+            solid = cq.Workplane(self.workplane).polyline(
+                [
+                    p1[:2],
+                    p2[:2],
+                    p3[:2],
+                    p4[:2],
+                    p5[:2],
+                    p6[:2],
+                    p7[:2],
+                    p8[:2],
+                    p9[:2],
+                    p10[:2],
+                ]
             )
 
             wire = solid.close()
@@ -187,9 +202,7 @@ class PoloidalFieldCoilCaseSetFC(RotateStraightShape):
 
             pf_coils_set.append(solid)
 
-        compound = cq.Compound.makeCompound(
-            [a.val() for a in pf_coils_set]
-        )
+        compound = cq.Compound.makeCompound([a.val() for a in pf_coils_set])
 
         self.wire = wires
 
