@@ -1,4 +1,3 @@
-
 from paramak import Plasma
 
 
@@ -16,15 +15,10 @@ class PlasmaFromPoints(Plasma):
     """
 
     def __init__(
-        self,
-        outer_equatorial_x_point,
-        inner_equatorial_x_point,
-        high_point,
-        **kwargs
+        self, outer_equatorial_x_point, inner_equatorial_x_point, high_point, **kwargs
     ):
 
-        minor_radius = (outer_equatorial_x_point -
-                        inner_equatorial_x_point) / 2.0
+        minor_radius = (outer_equatorial_x_point - inner_equatorial_x_point) / 2.0
         major_radius = inner_equatorial_x_point + minor_radius
         elongation = high_point[1] / minor_radius
         triangularity = (major_radius - high_point[0]) / minor_radius
