@@ -1,6 +1,6 @@
+from plasmaboundaries import get_separatrix_coordinates
 
 from paramak import Plasma
-from plasmaboundaries import get_separatrix_coordinates
 
 
 class PlasmaBoundaries(Plasma):
@@ -65,8 +65,7 @@ class PlasmaBoundaries(Plasma):
             "elongation": self.elongation,
             "triangularity": self.triangularity,
         }
-        points = get_separatrix_coordinates(
-            params, self.configuration)
+        points = get_separatrix_coordinates(params, self.configuration)
         # add vertical displacement
         points[:, 1] += self.vertical_displacement
         # rescale to cm
@@ -83,5 +82,6 @@ class PlasmaBoundaries(Plasma):
                 upper_point_y = self.upper_x_point[1]
 
         points = points[
-            (points[:, 1] >= lower_point_y) & (points[:, 1] <= upper_point_y)]
+            (points[:, 1] >= lower_point_y) & (points[:, 1] <= upper_point_y)
+        ]
         self.points = points.tolist()[:-1]
