@@ -1,7 +1,7 @@
-
 from typing import Optional
 
 import cadquery as cq
+
 from paramak import RotateStraightShape
 
 
@@ -21,15 +21,13 @@ class VacuumVesselInnerLeg(RotateStraightShape):
         inner_radius: float,
         inner_leg_radius: float,
         thickness: float,
-        **kwargs
+        **kwargs,
     ):
         self.inner_height = inner_height
         self.inner_radius = inner_radius
         self.inner_leg_radius = inner_leg_radius
         self.thickness = thickness
-        super().__init__(
-            **kwargs
-        )
+        super().__init__(**kwargs)
 
     @property
     def inner_height(self):
@@ -39,10 +37,10 @@ class VacuumVesselInnerLeg(RotateStraightShape):
     def inner_height(self, value):
         if not isinstance(value, (float, int)):
             raise ValueError(
-                'VacuumVesselInnerLeg.inner_height must be a number. Not', value)
+                "VacuumVesselInnerLeg.inner_height must be a number. Not", value
+            )
         if value <= 0:
-            msg = (
-                f'VacuumVesselInnerLeg.inner_height must be a positive number above 0. Not {value}')
+            msg = f"VacuumVesselInnerLeg.inner_height must be a positive number above 0. Not {value}"
             raise ValueError(msg)
         self._inner_height = value
 
@@ -53,48 +51,52 @@ class VacuumVesselInnerLeg(RotateStraightShape):
     @inner_radius.setter
     def inner_radius(self, value):
         if not isinstance(value, (float, int)):
-            msg = (
-                f'VacuumVesselInnerLeg.inner_radius must be a number. Not {value}')
+            msg = f"VacuumVesselInnerLeg.inner_radius must be a number. Not {value}"
             raise ValueError(msg)
         if value <= 0:
-            msg = (
-                f'VacuumVesselInnerLeg.inner_radius must be a positive number above 0. Not {value}')
+            msg = f"VacuumVesselInnerLeg.inner_radius must be a positive number above 0. Not {value}"
             raise ValueError(msg)
 
         self._inner_radius = value
 
     def find_points(self):
         """Finds the XZ points joined by straight connections that describe the
-            2D profile of the vessel shape."""
+        2D profile of the vessel shape."""
         thickness = self.thickness
         inner_radius = self.inner_radius
         inner_height = self.inner_height
         inner_leg_radius = self.inner_leg_radius
 
-        point_1 = (inner_leg_radius + 2 * thickness +
-                   inner_radius, thickness + (inner_height / 2.))
-        point_2 = (0, thickness + (inner_height / 2.))
-        point_3 = (0, -(thickness + (inner_height / 2.)))
-        point_4 = (inner_leg_radius + 2 * thickness +
-                   inner_radius, -(thickness + (inner_height / 2)))
+        point_1 = (
+            inner_leg_radius + 2 * thickness + inner_radius,
+            thickness + (inner_height / 2.0),
+        )
+        point_2 = (0, thickness + (inner_height / 2.0))
+        point_3 = (0, -(thickness + (inner_height / 2.0)))
+        point_4 = (
+            inner_leg_radius + 2 * thickness + inner_radius,
+            -(thickness + (inner_height / 2)),
+        )
 
-        point_5 = (
-            inner_leg_radius +
-            thickness +
-            inner_radius,
-            inner_height /
-            2)
+        point_5 = (inner_leg_radius + thickness + inner_radius, inner_height / 2)
         point_6 = (inner_leg_radius + thickness, inner_height / 2)
         point_7 = (inner_leg_radius + thickness, -inner_height / 2)
-        point_8 = (inner_leg_radius + thickness +
-                   inner_radius, -inner_height / 2)
+        point_8 = (inner_leg_radius + thickness + inner_radius, -inner_height / 2)
 
         points_9 = (inner_leg_radius, thickness + inner_height / 2)
         points_10 = (inner_leg_radius, -(thickness + inner_height / 2))
 
         self.points = [
-            point_1, point_2, point_3, point_4, point_5, point_6, point_7,
-            point_8, points_9, points_10
+            point_1,
+            point_2,
+            point_3,
+            point_4,
+            point_5,
+            point_6,
+            point_7,
+            point_8,
+            points_9,
+            points_10,
         ]
 
     def create_solid(self):
@@ -110,25 +112,17 @@ class VacuumVesselInnerLeg(RotateStraightShape):
         for point in self.points:
             local_points.append((point[0], point[1]))
 
-        big_wire = (
-            cq.Workplane(self.workplane)
-            .polyline(local_points[:4])
-        ).close()
+        big_wire = (cq.Workplane(self.workplane).polyline(local_points[:4])).close()
 
         small_wire = (
-            cq.Workplane(self.workplane)
-            .polyline(local_points[4:8])  # list of points has 10 entries
+            cq.Workplane(self.workplane).polyline(
+                local_points[4:8]
+            )  # list of points has 10 entries
         ).close()
 
         inner_wire = (
-            cq.Workplane(self.workplane)
-            .polyline(
-                [
-                    local_points[1],
-                    local_points[2],
-                    local_points[9],
-                    local_points[8]
-                ]
+            cq.Workplane(self.workplane).polyline(
+                [local_points[1], local_points[2], local_points[9], local_points[8]]
             )
         ).close()
 
