@@ -1,3 +1,4 @@
+from typing import List
 
 import paramak
 
@@ -24,8 +25,8 @@ class SparcFrom2020PaperDiagram(paramak.Reactor):
         self.rotation_angle = rotation_angle
 
         # adds self.input_variable_names from the Reactor class
-        self.input_variable_names = self.input_variable_names + [
-            'rotation_angle',
+        self.input_variable_names: List[str] = self.input_variable_names + [
+            "rotation_angle",
         ]
 
     def create_pf_coils(self):
@@ -36,48 +37,101 @@ class SparcFrom2020PaperDiagram(paramak.Reactor):
 
         """
 
-        inboard_pf_coils = paramak.PoloidalFieldCoilSet(
-            center_points=[
-                (53.5, -169.58),
-                (53.5, -118.43),
-                (53.5, -46.54),
-                (53.5, 46.54),
-                (53.5, 118.43),
-                (53.5, 169.58),
-            ],
-            heights=[41.5, 40.5, 82.95, 82.95, 40.5, 41.5, ],
-            widths=[27.7, 27.7, 27.7, 27.7, 27.7, 27.7],
-            rotation_angle=self.rotation_angle,
-        )
+        center_points = [
+            (53.5, -169.58),
+            (53.5, -118.43),
+            (53.5, -46.54),
+            (53.5, 46.54),
+            (53.5, 118.43),
+            (53.5, 169.58),
+        ]
+        heights = [
+            41.5,
+            40.5,
+            82.95,
+            82.95,
+            40.5,
+            41.5,
+        ]
+        widths = [27.7, 27.7, 27.7, 27.7, 27.7, 27.7]
 
-        outboard_pf_coils = paramak.PoloidalFieldCoilSet(
-            center_points=[
-                (86, 230),
-                (86, -230),
-                (164, 241),
-                (164, -241),
-                (263, 222),
-                (263, -222),
-                (373, 131),
-                (373, -131),
-            ],
-            widths=[32, 32, 50, 50, 43, 43, 48, 48, ],
-            heights=[40, 40, 30, 30, 28, 28, 37, 37, ],
-            rotation_angle=self.rotation_angle,
-        )
+        inboard_pf_coils = []
+        for counter, (center_point, width, height) in enumerate(
+            zip(center_points, widths, heights), 1
+        ):
+            pf_coil = paramak.PoloidalFieldCoil(
+                height=height,
+                width=width,
+                center_point=center_point,
+                rotation_angle=self.rotation_angle,
+                name=f"inboard_pf_coil_{counter}",
+            )
+            inboard_pf_coils.append(pf_coil)
 
-        div_coils = paramak.PoloidalFieldCoilSet(
-            center_points=[
-                (207, 144),
-                (207, 125),
-                (207, -144),
-                (207, -125),
+        center_points = [
+            (86, 230),
+            (86, -230),
+            (164, 241),
+            (164, -241),
+            (263, 222),
+            (263, -222),
+            (373, 131),
+            (373, -131),
+        ]
+        widths = [
+            32,
+            32,
+            50,
+            50,
+            43,
+            43,
+            48,
+            48,
+        ]
+        heights = [
+            40,
+            40,
+            30,
+            30,
+            28,
+            28,
+            37,
+            37,
+        ]
+        outboard_pf_coils = []
+        for counter, (center_point, width, height) in enumerate(
+            zip(center_points, widths, heights), 1
+        ):
+            pf_coil = paramak.PoloidalFieldCoil(
+                height=height,
+                width=width,
+                center_point=center_point,
+                rotation_angle=self.rotation_angle,
+                name=f"outboard_pf_coil_{counter}",
+            )
+            outboard_pf_coils.append(pf_coil)
 
-            ],
-            widths=[15, 15, 15, 15],
-            heights=[15, 15, 15, 15],
-            rotation_angle=self.rotation_angle,
-        )
+        center_points = [
+            (207, 144),
+            (207, 125),
+            (207, -144),
+            (207, -125),
+        ]
+        widths = [15, 15, 15, 15]
+        heights = [15, 15, 15, 15]
+
+        div_coils = []
+        for counter, (center_point, width, height) in enumerate(
+            zip(center_points, widths, heights), 1
+        ):
+            pf_coil = paramak.PoloidalFieldCoil(
+                height=height,
+                width=width,
+                center_point=center_point,
+                rotation_angle=self.rotation_angle,
+                name=f"div_coil_{counter}",
+            )
+            div_coils.append(pf_coil)
 
         efccu_coils_1 = paramak.RotateStraightShape(
             points=[
@@ -87,6 +141,7 @@ class SparcFrom2020PaperDiagram(paramak.Reactor):
                 (242.0323325635104, -132.25806451612902),
             ],
             rotation_angle=self.rotation_angle,
+            name="efccu_coils_1",
         )
 
         efccu_coils_2 = paramak.RotateStraightShape(
@@ -97,6 +152,7 @@ class SparcFrom2020PaperDiagram(paramak.Reactor):
                 (268.82217090069287, -94.47004608294935),
             ],
             rotation_angle=self.rotation_angle,
+            name="efccu_coils_2",
         )
 
         efccu_coils_3 = paramak.RotateStraightShape(
@@ -107,6 +163,7 @@ class SparcFrom2020PaperDiagram(paramak.Reactor):
                 (281.7551963048499, -78.80184331797238),
             ],
             rotation_angle=self.rotation_angle,
+            name="efccu_coils_3",
         )
 
         efccu_coils_4 = paramak.RotateStraightShape(
@@ -117,6 +174,7 @@ class SparcFrom2020PaperDiagram(paramak.Reactor):
                 (242.0323325635104, 132.25806451612902),
             ],
             rotation_angle=self.rotation_angle,
+            name="efccu_coils_4",
         )
 
         efccu_coils_5 = paramak.RotateStraightShape(
@@ -127,6 +185,7 @@ class SparcFrom2020PaperDiagram(paramak.Reactor):
                 (268.82217090069287, 94.47004608294935),
             ],
             rotation_angle=self.rotation_angle,
+            name="efccu_coils_5",
         )
 
         efccu_coils_6 = paramak.RotateStraightShape(
@@ -137,30 +196,50 @@ class SparcFrom2020PaperDiagram(paramak.Reactor):
                 (281.7551963048499, 78.80184331797238),
             ],
             rotation_angle=self.rotation_angle,
+            name="efccu_coils_6",
         )
 
         # these are cut away from the vessel components
-        vs_coils = paramak.PoloidalFieldCoilSet(
-            center_points=[
-                (240, 70),
-                (240, -70),
-            ],
-            widths=[10, 10],
-            heights=[10, 10],
-            rotation_angle=self.rotation_angle,
-        )
-
-        return [
-            inboard_pf_coils, outboard_pf_coils, div_coils,
-            efccu_coils_1, efccu_coils_2, efccu_coils_3,
-            efccu_coils_4, efccu_coils_5, efccu_coils_6, vs_coils
+        center_points = [
+            (240, 70),
+            (240, -70),
         ]
+        widths = [10, 10]
+        heights = [10, 10]
+
+        vs_coils = []
+        for counter, (center_point, width, height) in enumerate(
+            zip(center_points, widths, heights), 1
+        ):
+            pf_coil = paramak.PoloidalFieldCoil(
+                height=height,
+                width=width,
+                center_point=center_point,
+                rotation_angle=self.rotation_angle,
+                name=f"vs_coil_{counter}",
+            )
+            vs_coils.append(pf_coil)
+
+        return (
+            vs_coils
+            + inboard_pf_coils
+            + outboard_pf_coils
+            + div_coils
+            + [
+                efccu_coils_1,
+                efccu_coils_2,
+                efccu_coils_3,
+                efccu_coils_4,
+                efccu_coils_5,
+                efccu_coils_6,
+            ]
+        )
 
     def create_tf_coils(self):
         """Creates a 3d solids for each tf coil.
 
-           Returns:
-              A list of CadQuery solids: A list of 3D solid volumes
+        Returns:
+           A list of CadQuery solids: A list of 3D solid volumes
 
         """
 
@@ -171,6 +250,7 @@ class SparcFrom2020PaperDiagram(paramak.Reactor):
             distance=33,
             number_of_coils=12,
             rotation_angle=self.rotation_angle,
+            name="tf_coil",
         )
 
         return [tf_coil]
@@ -190,13 +270,14 @@ class SparcFrom2020PaperDiagram(paramak.Reactor):
 
         antenna = paramak.RotateMixedShape(
             points=[
-                (263.2794457274827, 46.5437788018433, 'straight'),
-                (263.2794457274827, -46.54377880184336, 'straight'),
-                (231.87066974595842, -46.54377880184336, 'spline'),
-                (243.87990762124713, 0, 'spline'),
-                (231.87066974595842, 46.5437788018433, 'straight'),
+                (263.2794457274827, 46.5437788018433, "straight"),
+                (263.2794457274827, -46.54377880184336, "straight"),
+                (231.87066974595842, -46.54377880184336, "spline"),
+                (243.87990762124713, 0, "spline"),
+                (231.87066974595842, 46.5437788018433, "straight"),
             ],
             rotation_angle=self.rotation_angle,
+            name="antenna",
         )
 
         vac_vessel = paramak.RotateStraightShape(
@@ -236,58 +317,60 @@ class SparcFrom2020PaperDiagram(paramak.Reactor):
                 (117.32101616628177, 123.04147465437785),
             ],
             rotation_angle=self.rotation_angle,
-            color=(0., 1., 1.),
+            color=(0.0, 1.0, 1.0),
+            name="vessel",
         )
 
         inner_vessel = paramak.RotateMixedShape(
             points=[
-                (269.7459584295612, -46.54377880184336, 'straight'),
-                (231.87066974595842, -46.5437788018433, 'spline'),
-                (223.55658198614316, -62.21198156682027, 'spline'),
-                (207.85219399538107, -80.64516129032262, 'spline'),
-                (166.28175519630486, -115.66820276497697, 'spline'),
-                (164.43418013856814, -119.35483870967744, 'spline'),
-                (164.43418013856814, -122.11981566820276, 'straight'),
-                (173.67205542725173, -140.5529953917051, 'straight'),
-                (184.75750577367205, -140.5529953917051, 'straight'),
-                (184.75750577367205, -158.98617511520735, 'straight'),
-                (181.98614318706697, -159.9078341013825, 'straight'),
-                (147.80600461893764, -118.43317972350235, 'straight'),
-                (129.33025404157044, -123.04147465437785, 'straight'),
-                (145.95842956120094, -111.05990783410135, 'straight'),
-                (126.55889145496536, -50.23041474654377, 'straight'),
-                (127.48267898383372, 50.23041474654377, 'straight'),
-                (145.95842956120094, 110.13824884792626, 'straight'),
-                (128.40646651270208, 123.04147465437785, 'straight'),
-                (147.80600461893764, 117.51152073732717, 'straight'),
-                (181.98614318706697, 159.90783410138246, 'straight'),
-                (185.6812933025404, 158.98617511520735, 'straight'),
-                (184.75750577367205, 140.55299539170505, 'straight'),
-                (172.74826789838338, 140.55299539170505, 'spline'),
-                (164.43418013856814, 121.19815668202764, 'spline'),
-                (164.43418013856814, 118.43317972350229, 'spline'),
-                (165.3579676674365, 115.66820276497694, 'spline'),
-                (173.67205542725173, 111.05990783410135, 'spline'),
-                (207.85219399538107, 80.64516129032256, 'spline'),
-                (220.7852193995381, 66.82027649769586, 'spline'),
-                (231.87066974595842, 46.5437788018433, 'spline'),
-                (268.82217090069287, 46.5437788018433, 'straight'),
-                (268.82217090069287, 63.13364055299536, 'straight'),
-                (233.71824480369514, 111.98156682027647, 'straight'),
-                (193.99538106235568, 112.90322580645159, 'straight'),
-                (192.14780600461893, 164.51612903225805, 'straight'),
-                (163.51039260969978, 166.35944700460828, 'straight'),
-                (121.93995381062356, 123.96313364055297, 'straight'),
-                (121.0161662817552, -125.80645161290323, 'straight'),
-                (163.51039260969978, -166.35944700460834, 'straight'),
-                (192.14780600461893, -166.35944700460834, 'straight'),
-                (193.99538106235568, -112.90322580645159, 'straight'),
-                (234.64203233256353, -111.9815668202765, 'straight'),
-                (269.7459584295612, -63.13364055299536, 'straight'),
+                (269.7459584295612, -46.54377880184336, "straight"),
+                (231.87066974595842, -46.5437788018433, "spline"),
+                (223.55658198614316, -62.21198156682027, "spline"),
+                (207.85219399538107, -80.64516129032262, "spline"),
+                (166.28175519630486, -115.66820276497697, "spline"),
+                (164.43418013856814, -119.35483870967744, "spline"),
+                (164.43418013856814, -122.11981566820276, "straight"),
+                (173.67205542725173, -140.5529953917051, "straight"),
+                (184.75750577367205, -140.5529953917051, "straight"),
+                (184.75750577367205, -158.98617511520735, "straight"),
+                (181.98614318706697, -159.9078341013825, "straight"),
+                (147.80600461893764, -118.43317972350235, "straight"),
+                (129.33025404157044, -123.04147465437785, "straight"),
+                (145.95842956120094, -111.05990783410135, "straight"),
+                (126.55889145496536, -50.23041474654377, "straight"),
+                (127.48267898383372, 50.23041474654377, "straight"),
+                (145.95842956120094, 110.13824884792626, "straight"),
+                (128.40646651270208, 123.04147465437785, "straight"),
+                (147.80600461893764, 117.51152073732717, "straight"),
+                (181.98614318706697, 159.90783410138246, "straight"),
+                (185.6812933025404, 158.98617511520735, "straight"),
+                (184.75750577367205, 140.55299539170505, "straight"),
+                (172.74826789838338, 140.55299539170505, "spline"),
+                (164.43418013856814, 121.19815668202764, "spline"),
+                (164.43418013856814, 118.43317972350229, "spline"),
+                (165.3579676674365, 115.66820276497694, "spline"),
+                (173.67205542725173, 111.05990783410135, "spline"),
+                (207.85219399538107, 80.64516129032256, "spline"),
+                (220.7852193995381, 66.82027649769586, "spline"),
+                (231.87066974595842, 46.5437788018433, "spline"),
+                (268.82217090069287, 46.5437788018433, "straight"),
+                (268.82217090069287, 63.13364055299536, "straight"),
+                (233.71824480369514, 111.98156682027647, "straight"),
+                (193.99538106235568, 112.90322580645159, "straight"),
+                (192.14780600461893, 164.51612903225805, "straight"),
+                (163.51039260969978, 166.35944700460828, "straight"),
+                (121.93995381062356, 123.96313364055297, "straight"),
+                (121.0161662817552, -125.80645161290323, "straight"),
+                (163.51039260969978, -166.35944700460834, "straight"),
+                (192.14780600461893, -166.35944700460834, "straight"),
+                (193.99538106235568, -112.90322580645159, "straight"),
+                (234.64203233256353, -111.9815668202765, "straight"),
+                (269.7459584295612, -63.13364055299536, "straight"),
             ],
             rotation_angle=self.rotation_angle,
-            cut=[vac_vessel, vs_coils, antenna],
-            color=(0., 1., 0.498),
+            cut=[vac_vessel, antenna] + vs_coils,
+            color=(0.0, 1.0, 0.498),
+            name="inner_vessel",
         )
 
         return [antenna, vac_vessel, inner_vessel]
@@ -325,7 +408,7 @@ class SparcFrom2020PaperDiagram(paramak.Reactor):
         plasma = self.create_plasma()
         pf_coils = self.create_pf_coils()
         tf_coils = self.create_tf_coils()
-        vessel = self.create_vessel_components(pf_coils[-1])
+        vessel = self.create_vessel_components([pf_coils[0], pf_coils[1]])
 
         all_shapes_and_components = plasma + pf_coils + tf_coils + vessel
 
