@@ -1,8 +1,8 @@
-
 import warnings
-from typing import List, Optional, Union
+from typing import List, Optional
 
 import cadquery as cq
+
 import paramak
 
 
@@ -56,7 +56,7 @@ class SubmersionTokamak(paramak.Reactor):
 
     def __init__(
         self,
-        inner_bore_radial_thickness: float = 30.,
+        inner_bore_radial_thickness: float = 30.0,
         inboard_tf_leg_radial_thickness: float = 30,
         center_column_shield_radial_thickness: float = 30,
         inboard_blanket_radial_thickness: float = 80,
@@ -68,18 +68,18 @@ class SubmersionTokamak(paramak.Reactor):
         outer_plasma_gap_radial_thickness: float = 50,
         outboard_blanket_radial_thickness: float = 30,
         blanket_rear_wall_radial_thickness: float = 30,
-        elongation: float = 2.,
+        elongation: float = 2.0,
         triangularity: float = 0.5,
         number_of_tf_coils: int = 16,
-        rotation_angle: float = 360.,
+        rotation_angle: float = 360.0,
         outboard_tf_coil_radial_thickness: Optional[float] = None,
         rear_blanket_to_tf_gap: Optional[float] = None,
         outboard_tf_coil_poloidal_thickness: Optional[float] = None,
-        pf_coil_vertical_thicknesses: Optional[float] = None,
-        pf_coil_radial_thicknesses: Optional[float] = None,
-        pf_coil_radial_position: Optional[Union[float, List[float]]] = None,
-        pf_coil_vertical_position: Optional[Union[float, List[float]]] = None,
-        pf_coil_case_thicknesses: Optional[float] = 10,
+        pf_coil_radial_thicknesses: List[float] = [],
+        pf_coil_vertical_thicknesses: List[float] = [],
+        pf_coil_radial_position: List[float] = [],
+        pf_coil_vertical_position: List[float] = [],
+        pf_coil_case_thicknesses: List[float] = [],
         divertor_position: Optional[str] = "both",
         support_position: Optional[str] = "both",
     ):
@@ -91,29 +91,21 @@ class SubmersionTokamak(paramak.Reactor):
         self.center_column_shield_radial_thickness = (
             center_column_shield_radial_thickness
         )
-        self.inboard_blanket_radial_thickness = \
-            inboard_blanket_radial_thickness
+        self.inboard_blanket_radial_thickness = inboard_blanket_radial_thickness
         self.firstwall_radial_thickness = firstwall_radial_thickness
-        self.inner_plasma_gap_radial_thickness = \
-            inner_plasma_gap_radial_thickness
+        self.inner_plasma_gap_radial_thickness = inner_plasma_gap_radial_thickness
         self.plasma_radial_thickness = plasma_radial_thickness
-        self.outer_plasma_gap_radial_thickness = \
-            outer_plasma_gap_radial_thickness
-        self.outboard_blanket_radial_thickness = \
-            outboard_blanket_radial_thickness
-        self.blanket_rear_wall_radial_thickness = \
-            blanket_rear_wall_radial_thickness
+        self.outer_plasma_gap_radial_thickness = outer_plasma_gap_radial_thickness
+        self.outboard_blanket_radial_thickness = outboard_blanket_radial_thickness
+        self.blanket_rear_wall_radial_thickness = blanket_rear_wall_radial_thickness
         self.pf_coil_radial_thicknesses = pf_coil_radial_thicknesses
-        self.outboard_tf_coil_radial_thickness = \
-            outboard_tf_coil_radial_thickness
-        self.outboard_tf_coil_poloidal_thickness = \
-            outboard_tf_coil_poloidal_thickness
+        self.outboard_tf_coil_radial_thickness = outboard_tf_coil_radial_thickness
+        self.outboard_tf_coil_poloidal_thickness = outboard_tf_coil_poloidal_thickness
         self.divertor_radial_thickness = divertor_radial_thickness
         self.support_radial_thickness = support_radial_thickness
         self.elongation = elongation
         self.triangularity = triangularity
-        self.rear_blanket_to_tf_gap = \
-            rear_blanket_to_tf_gap
+        self.rear_blanket_to_tf_gap = rear_blanket_to_tf_gap
         self.pf_coil_vertical_thicknesses = pf_coil_vertical_thicknesses
         self.pf_coil_case_thicknesses = pf_coil_case_thicknesses
         self.number_of_tf_coils = number_of_tf_coils
@@ -124,39 +116,45 @@ class SubmersionTokamak(paramak.Reactor):
         self.pf_coil_radial_position = pf_coil_radial_position
 
         # adds self.input_variable_names from the Reactor class
-        self.input_variable_names = self.input_variable_names + [
-            'inner_bore_radial_thickness',
-            'inboard_tf_leg_radial_thickness',
-            'center_column_shield_radial_thickness',
-            'inboard_blanket_radial_thickness',
-            'firstwall_radial_thickness',
-            'inner_plasma_gap_radial_thickness',
-            'plasma_radial_thickness',
-            'divertor_radial_thickness',
-            'support_radial_thickness',
-            'outer_plasma_gap_radial_thickness',
-            'outboard_blanket_radial_thickness',
-            'blanket_rear_wall_radial_thickness',
-            'elongation',
-            'triangularity',
-            'number_of_tf_coils',
-            'rotation_angle',
-            'outboard_tf_coil_radial_thickness',
-            'rear_blanket_to_tf_gap',
-            'outboard_tf_coil_poloidal_thickness',
-            'pf_coil_vertical_thicknesses',
-            'pf_coil_radial_thicknesses',
-            'pf_coil_radial_position',
-            'pf_coil_vertical_position',
-            'pf_coil_case_thicknesses',
-            'divertor_position',
-            'support_position',
+        self.input_variable_names: List[str] = self.input_variable_names + [
+            "inner_bore_radial_thickness",
+            "inboard_tf_leg_radial_thickness",
+            "center_column_shield_radial_thickness",
+            "inboard_blanket_radial_thickness",
+            "firstwall_radial_thickness",
+            "inner_plasma_gap_radial_thickness",
+            "plasma_radial_thickness",
+            "divertor_radial_thickness",
+            "support_radial_thickness",
+            "outer_plasma_gap_radial_thickness",
+            "outboard_blanket_radial_thickness",
+            "blanket_rear_wall_radial_thickness",
+            "elongation",
+            "triangularity",
+            "number_of_tf_coils",
+            "rotation_angle",
+            "outboard_tf_coil_radial_thickness",
+            "rear_blanket_to_tf_gap",
+            "outboard_tf_coil_poloidal_thickness",
+            "pf_coil_vertical_thicknesses",
+            "pf_coil_radial_thicknesses",
+            "pf_coil_radial_position",
+            "pf_coil_vertical_position",
+            "pf_coil_case_thicknesses",
+            "divertor_position",
+            "support_position",
         ]
 
         # set by make_plasma
         self.major_radius = None
         self.minor_radius = None
 
+        # set during geometry creation
+        self._pf_coils = None
+        self._pf_coils_casing = None
+        self._divertor_lower = None
+        self._divertor_upper = None
+
     @property
     def pf_coil_radial_position(self):
         return self._pf_coil_radial_position
@@ -227,7 +225,7 @@ class SubmersionTokamak(paramak.Reactor):
         uncut_shapes.append(self._make_center_column_shield())
         uncut_shapes.append(self._make_firstwall())
         uncut_shapes.append(self._make_blanket())
-        uncut_shapes.append(self._make_divertor())
+        uncut_shapes += self._make_divertor()
         uncut_shapes.append(self._make_supports())
         uncut_shapes.append(self._make_rear_blanket_wall())
         uncut_shapes += self._make_tf_coils()
@@ -246,8 +244,10 @@ class SubmersionTokamak(paramak.Reactor):
     def _rotation_angle_check(self):
 
         if self.rotation_angle == 360:
-            msg = "360 degree rotation may result" + \
-                " in a Standard_ConstructionError or AttributeError"
+            msg = (
+                "360 degree rotation may result"
+                + " in a Standard_ConstructionError or AttributeError"
+            )
             warnings.warn(msg, UserWarning)
 
     def _make_radial_build(self):
@@ -262,60 +262,55 @@ class SubmersionTokamak(paramak.Reactor):
 
         self._inboard_tf_coils_start_radius = self._inner_bore_end_radius
         self._inboard_tf_coils_end_radius = (
-            self._inboard_tf_coils_start_radius +
-            self.inboard_tf_leg_radial_thickness)
+            self._inboard_tf_coils_start_radius + self.inboard_tf_leg_radial_thickness
+        )
 
-        self._center_column_shield_start_radius = \
-            self._inboard_tf_coils_end_radius
+        self._center_column_shield_start_radius = self._inboard_tf_coils_end_radius
         self._center_column_shield_end_radius = (
             self._center_column_shield_start_radius
             + self.center_column_shield_radial_thickness
         )
 
-        self._inboard_blanket_start_radius = \
-            self._center_column_shield_end_radius
+        self._inboard_blanket_start_radius = self._center_column_shield_end_radius
         self._inboard_blanket_end_radius = (
-            self._inboard_blanket_start_radius +
-            self.inboard_blanket_radial_thickness)
+            self._inboard_blanket_start_radius + self.inboard_blanket_radial_thickness
+        )
 
         self._inboard_firstwall_start_radius = self._inboard_blanket_end_radius
         self._inboard_firstwall_end_radius = (
-            self._inboard_firstwall_start_radius +
-            self.firstwall_radial_thickness)
+            self._inboard_firstwall_start_radius + self.firstwall_radial_thickness
+        )
 
-        self._inner_plasma_gap_start_radius = \
-            self._inboard_firstwall_end_radius
+        self._inner_plasma_gap_start_radius = self._inboard_firstwall_end_radius
         self._inner_plasma_gap_end_radius = (
-            self._inner_plasma_gap_start_radius +
-            self.inner_plasma_gap_radial_thickness)
+            self._inner_plasma_gap_start_radius + self.inner_plasma_gap_radial_thickness
+        )
 
         self._plasma_start_radius = self._inner_plasma_gap_end_radius
-        self._plasma_end_radius = \
-            self._plasma_start_radius + \
-            self.plasma_radial_thickness
+        self._plasma_end_radius = (
+            self._plasma_start_radius + self.plasma_radial_thickness
+        )
 
         self._outer_plasma_gap_start_radius = self._plasma_end_radius
         self._outer_plasma_gap_end_radius = (
-            self._outer_plasma_gap_start_radius +
-            self.outer_plasma_gap_radial_thickness)
+            self._outer_plasma_gap_start_radius + self.outer_plasma_gap_radial_thickness
+        )
 
-        self._outboard_firstwall_start_radius = \
-            self._outer_plasma_gap_end_radius
+        self._outboard_firstwall_start_radius = self._outer_plasma_gap_end_radius
         self._outboard_firstwall_end_radius = (
-            self._outboard_firstwall_start_radius +
-            self.firstwall_radial_thickness)
+            self._outboard_firstwall_start_radius + self.firstwall_radial_thickness
+        )
 
-        self._outboard_blanket_start_radius = \
-            self._outboard_firstwall_end_radius
+        self._outboard_blanket_start_radius = self._outboard_firstwall_end_radius
         self._outboard_blanket_end_radius = (
-            self._outboard_blanket_start_radius +
-            self.outboard_blanket_radial_thickness)
+            self._outboard_blanket_start_radius + self.outboard_blanket_radial_thickness
+        )
 
-        self._blanket_rear_wall_start_radius = \
-            self._outboard_blanket_end_radius
+        self._blanket_rear_wall_start_radius = self._outboard_blanket_end_radius
         self._blanket_rear_wall_end_radius = (
-            self._blanket_rear_wall_start_radius +
-            self.blanket_rear_wall_radial_thickness)
+            self._blanket_rear_wall_start_radius
+            + self.blanket_rear_wall_radial_thickness
+        )
 
         self._tf_info_provided = False
         if (
@@ -325,11 +320,12 @@ class SubmersionTokamak(paramak.Reactor):
         ):
             self._tf_info_provided = True
             self._outboard_tf_coil_start_radius = (
-                self._blanket_rear_wall_end_radius +
-                self.rear_blanket_to_tf_gap)
+                self._blanket_rear_wall_end_radius + self.rear_blanket_to_tf_gap
+            )
             self._outboard_tf_coil_end_radius = (
-                self._outboard_tf_coil_start_radius +
-                self.outboard_tf_coil_radial_thickness)
+                self._outboard_tf_coil_start_radius
+                + self.outboard_tf_coil_radial_thickness
+            )
 
         self._divertor_start_radius = (
             self._plasma.high_point[0] - 0.5 * self.divertor_radial_thickness
@@ -355,13 +351,15 @@ class SubmersionTokamak(paramak.Reactor):
 
         self._plasma_to_divertor_gap_start_height = self._plasma_end_height
         self._plasma_to_divertor_gap_end_height = (
-            self._plasma_to_divertor_gap_start_height +
-            self.outer_plasma_gap_radial_thickness)
+            self._plasma_to_divertor_gap_start_height
+            + self.outer_plasma_gap_radial_thickness
+        )
 
         # the firstwall is cut by the divertor but uses the same control points
         self._firstwall_start_height = self._plasma_to_divertor_gap_end_height
-        self._firstwall_end_height = self._firstwall_start_height + \
-            self.firstwall_radial_thickness
+        self._firstwall_end_height = (
+            self._firstwall_start_height + self.firstwall_radial_thickness
+        )
 
         self._blanket_start_height = self._firstwall_end_height
         self._blanket_end_height = (
@@ -370,14 +368,17 @@ class SubmersionTokamak(paramak.Reactor):
 
         self._blanket_rear_wall_start_height = self._blanket_end_height
         self._blanket_rear_wall_end_height = (
-            self._blanket_rear_wall_start_height +
-            self.blanket_rear_wall_radial_thickness)
+            self._blanket_rear_wall_start_height
+            + self.blanket_rear_wall_radial_thickness
+        )
 
         if self._tf_info_provided:
-            self._outboard_tf_coils_vertical_height = \
+            self._outboard_tf_coils_vertical_height = (
                 self._blanket_rear_wall_end_height * 1.5
-            self._outboard_tf_coils_horizontal_length = \
+            )
+            self._outboard_tf_coils_horizontal_length = (
                 self._blanket_rear_wall_end_radius * 0.75
+            )
 
     def _make_center_column_shield(self):
 
@@ -403,10 +404,8 @@ class SubmersionTokamak(paramak.Reactor):
             + self.firstwall_radial_thickness
             + self.inner_plasma_gap_radial_thickness
         )
-        outer_equatorial_point = \
-            inner_equatorial_point + self.plasma_radial_thickness
-        self.major_radius = \
-            (outer_equatorial_point + inner_equatorial_point) / 2
+        outer_equatorial_point = inner_equatorial_point + self.plasma_radial_thickness
+        self.major_radius = (outer_equatorial_point + inner_equatorial_point) / 2
         self.minor_radius = self.major_radius - inner_equatorial_point
 
         plasma = paramak.Plasma(
@@ -472,27 +471,45 @@ class SubmersionTokamak(paramak.Reactor):
         divertor_height_top = divertor_height
         divertor_height_bottom = -divertor_height
 
+        if self.divertor_position in ["lower", "both"]:
+            self._divertor_lower = paramak.RotateStraightShape(
+                points=[
+                    (self._divertor_start_radius, divertor_height_bottom),
+                    (self._divertor_end_radius, divertor_height_bottom),
+                    (self._divertor_end_radius, 0),
+                    (self._divertor_start_radius, 0),
+                ],
+                intersect=fw_envelope,
+                name="divertor_lower",
+                color=(1.0, 0.667, 0.0),
+                rotation_angle=self.rotation_angle,
+            )
+        if self.divertor_position in ["upper", "both"]:
+            self._divertor_upper = paramak.RotateStraightShape(
+                points=[
+                    (self._divertor_start_radius, 0),
+                    (self._divertor_end_radius, 0),
+                    (self._divertor_end_radius, divertor_height_top),
+                    (self._divertor_start_radius, divertor_height_top),
+                ],
+                intersect=fw_envelope,
+                name="divertor_upper",
+                color=(1.0, 0.667, 0.0),
+                rotation_angle=self.rotation_angle,
+            )
+
+        for component in [self._firstwall, self._inboard_firstwall]:
+            if self.divertor_position in ["upper", "both"]:
+                component.cut = [self._divertor_upper]
+            if self.divertor_position in ["lower", "both"]:
+                component.cut = [self._divertor_lower]
+
+        if self.divertor_position == "upper":
+            return [self._divertor_upper]
         if self.divertor_position == "lower":
-            divertor_height_top = 0
-        elif self.divertor_position == "upper":
-            divertor_height_bottom = 0
-
-        self._divertor = paramak.RotateStraightShape(
-            points=[
-                (self._divertor_start_radius, divertor_height_bottom),
-                (self._divertor_end_radius, divertor_height_bottom),
-                (self._divertor_end_radius, divertor_height_top),
-                (self._divertor_start_radius, divertor_height_top)
-            ],
-            intersect=fw_envelope,
-            rotation_angle=self.rotation_angle,
-            name="divertor",
-            color=(1., 0.667, 0.),
-        )
-
-        self._firstwall.cut = self._divertor
-        self._inboard_firstwall.cut = self._divertor
-        return self._divertor
+            return [self._divertor_lower]
+        if self.divertor_position == "both":
+            return [self._divertor_upper, self._divertor_lower]
 
     def _make_blanket(self):
         self._inboard_blanket = paramak.CenterColumnShieldCylinder(
@@ -521,7 +538,7 @@ class SubmersionTokamak(paramak.Reactor):
             thickness=self.outboard_blanket_radial_thickness,
             rotation_angle=self.rotation_angle,
             name="blanket",
-            color=(0., 1., 0.498),
+            color=(0.0, 1.0, 0.498),
             union=self._inboard_blanket,
         )
         return self._blanket
@@ -551,11 +568,11 @@ class SubmersionTokamak(paramak.Reactor):
                 (self._support_start_radius, support_height_bottom),
                 (self._support_end_radius, support_height_bottom),
                 (self._support_end_radius, support_height_top),
-                (self._support_start_radius, support_height_top)
+                (self._support_start_radius, support_height_top),
             ],
             rotation_angle=self.rotation_angle,
             name="supports",
-            color=(0., 0., 0.),
+            color=(0.0, 0.0, 0.0),
             intersect=blanket_envelope,
         )
 
@@ -568,11 +585,11 @@ class SubmersionTokamak(paramak.Reactor):
             points=[
                 (
                     self._center_column_shield_end_radius,
-                    self._blanket_rear_wall_start_height
+                    self._blanket_rear_wall_start_height,
                 ),
                 (
                     self._center_column_shield_end_radius,
-                    self._blanket_rear_wall_end_height
+                    self._blanket_rear_wall_end_height,
                 ),
                 (
                     max(self._inboard_firstwall.points)[0],
@@ -590,11 +607,11 @@ class SubmersionTokamak(paramak.Reactor):
             points=[
                 (
                     self._center_column_shield_end_radius,
-                    -self._blanket_rear_wall_start_height
+                    -self._blanket_rear_wall_start_height,
                 ),
                 (
                     self._center_column_shield_end_radius,
-                    -self._blanket_rear_wall_end_height
+                    -self._blanket_rear_wall_end_height,
                 ),
                 (
                     max(self._inboard_firstwall.points)[0],
@@ -612,58 +629,91 @@ class SubmersionTokamak(paramak.Reactor):
             plasma=self._plasma,
             start_angle=90,
             stop_angle=-90,
-            offset_from_plasma=self.outer_plasma_gap_radial_thickness +
-            self.firstwall_radial_thickness +
-            self.outboard_blanket_radial_thickness,
+            offset_from_plasma=self.outer_plasma_gap_radial_thickness
+            + self.firstwall_radial_thickness
+            + self.outboard_blanket_radial_thickness,
             thickness=self.blanket_rear_wall_radial_thickness,
             rotation_angle=self.rotation_angle,
             name="outboard_rear_blanket_wall",
-            color=(0., 1., 1.),
+            color=(0.0, 1.0, 1.0),
             union=[
                 self._outboard_rear_blanket_wall_upper,
-                self._outboard_rear_blanket_wall_lower],
+                self._outboard_rear_blanket_wall_lower,
+            ],
         )
 
         return self._outboard_rear_blanket_wall
 
     def _make_pf_coils(self):
-        if None not in [self.pf_coil_vertical_thicknesses,
-                        self.pf_coil_radial_thicknesses,
-                        self.pf_coil_vertical_position,
-                        self.pf_coil_radial_position]:
-            list_of_components = []
 
-            # TODO make use of counter in the name attribute
+        pf_input_lists = [
+            self.pf_coil_vertical_thicknesses,
+            self.pf_coil_radial_thicknesses,
+            self.pf_coil_vertical_position,
+            self.pf_coil_radial_position,
+        ]
+
+        # checks if lists are all the same length
+        if all(
+            len(input_list) == len(pf_input_lists[0]) for input_list in pf_input_lists
+        ):
+            number_of_pf_coils = len(pf_input_lists[0])
+            if number_of_pf_coils == 0:
+                return None
 
             center_points = [
-                (x, y) for x, y in zip(
-                    self.pf_coil_radial_position, self.pf_coil_vertical_position)]
-
-            self._pf_coils = self._pf_coil = paramak.PoloidalFieldCoilSet(
-                heights=self.pf_coil_vertical_thicknesses,
-                widths=self.pf_coil_radial_thicknesses,
-                center_points=center_points,
-                rotation_angle=self.rotation_angle,
-                name="pf_coil",
-            )
-            list_of_components.append(self._pf_coil)
-
-            if self.pf_coil_case_thicknesses is not None:
-                self._pf_coils_casing = paramak.PoloidalFieldCoilCaseSetFC(
-                    pf_coils=self._pf_coil,
-                    casing_thicknesses=self.pf_coil_case_thicknesses,
-                    rotation_angle=self.rotation_angle,
-                    name="pf_coil_case",
+                (x, y)
+                for x, y in zip(
+                    self.pf_coil_radial_position, self.pf_coil_vertical_position
                 )
-                list_of_components.append(self._pf_coils_casing)
+            ]
 
-            return list_of_components
-        else:
-            print(
-                'pf_coil_vertical_thicknesses, pf_coil_radial_thicknesses, '
-                'pf_coil_radial_position, pf_coil_vertical_position not '
-                'so not making pf coils')
-            return None
+            self._pf_coils = []
+            for counter, (
+                center_point,
+                pf_coil_vertical_thickness,
+                pf_coil_radial_thickness,
+            ) in enumerate(
+                zip(
+                    center_points,
+                    self.pf_coil_vertical_thicknesses,
+                    self.pf_coil_radial_thicknesses,
+                ),
+                1,
+            ):
+                pf_coil = paramak.PoloidalFieldCoil(
+                    height=pf_coil_vertical_thickness,
+                    width=pf_coil_radial_thickness,
+                    center_point=center_point,
+                    rotation_angle=self.rotation_angle,
+                    name=f"pf_coil_{counter}",
+                )
+                self._pf_coils.append(pf_coil)
+
+            if self.pf_coil_case_thicknesses == []:
+                return self._pf_coils
+
+            self._pf_coils_casing = []
+            if len(self.pf_coil_case_thicknesses) == number_of_pf_coils:
+                for counter, (pf_coil_case_thickness, pf_coil) in enumerate(
+                    zip(self.pf_coil_case_thicknesses, self._pf_coils), 1
+                ):
+                    pf_coils_casing = paramak.PoloidalFieldCoilCaseFC(
+                        pf_coil=pf_coil,
+                        casing_thickness=pf_coil_case_thickness,
+                        rotation_angle=self.rotation_angle,
+                        name=f"pf_coil_case_{counter}",
+                    )
+                    self._pf_coils_casing.append(pf_coils_casing)
+            else:
+                raise ValueError(
+                    "pf_coil_case_thicknesses is not the same length as the other "
+                    "PF coil inputs (pf_coil_vertical_thicknesses, "
+                    "pf_coil_radial_thicknesses, pf_coil_radial_position, "
+                    "pf_coil_vertical_position) so can not make pf coils cases"
+                )
+
+            return self._pf_coils + self._pf_coils_casing
 
     def _make_tf_coils(self):
         list_of_components = []
@@ -678,11 +728,16 @@ class SubmersionTokamak(paramak.Reactor):
         )
         list_of_components.append(self._inboard_tf_coils)
 
-        if None not in [
+        if (
+            None
+            not in [
                 self.rear_blanket_to_tf_gap,
                 self.outboard_tf_coil_radial_thickness,
                 self.outboard_tf_coil_poloidal_thickness,
-                self.number_of_tf_coils] and self.number_of_tf_coils > 1:
+                self.number_of_tf_coils,
+            ]
+            and self.number_of_tf_coils > 1
+        ):
 
             if self._tf_info_provided:
                 self._tf_coil = paramak.ToroidalFieldCoilCoatHanger(
@@ -697,7 +752,8 @@ class SubmersionTokamak(paramak.Reactor):
                     distance=self.outboard_tf_coil_poloidal_thickness,
                     rotation_angle=self.rotation_angle,
                     horizontal_length=self._outboard_tf_coils_horizontal_length,
-                    vertical_length=self._outboard_tf_coils_vertical_height
+                    vertical_length=self._outboard_tf_coils_vertical_height,
+                    name="tf_coils",
                 )
                 list_of_components.append(self._tf_coil)
 
