@@ -1,7 +1,7 @@
-
 from typing import Optional, Tuple
 
 from cadquery import Workplane
+
 from paramak import Shape
 from paramak.utils import calculate_wedge_cut
 
@@ -23,23 +23,27 @@ class ExtrudeCircleShape(Shape):
         self,
         distance: float,
         radius: float,
-        extrusion_start_offset: Optional[float] = 0.0,
-        rotation_angle: Optional[float] = 360,
-        extrude_both: Optional[bool] = True,
-        color: Optional[Tuple[float, float, float, Optional[float]]] = (0.984, 0.603, 0.6),
+        extrusion_start_offset: float = 0.0,
+        rotation_angle: float = 360,
+        extrude_both: bool = True,
+        color: Tuple[float, float, float, Optional[float]] = (
+            0.984,
+            0.603,
+            0.6,
+        ),
+        name: str = "extrudecircleshape",
         **kwargs
     ):
 
-        super().__init__(
-            color=color,
-            **kwargs
-        )
+        super().__init__(color=color, name=name, **kwargs)
 
-        self.radius = radius
         self.distance = distance
+        self.radius = radius
+        self.extrusion_start_offset = extrusion_start_offset
         self.rotation_angle = rotation_angle
         self.extrude_both = extrude_both
-        self.extrusion_start_offset = extrusion_start_offset
+        self.color = color
+        self.name = name
 
     @property
     def radius(self):
@@ -76,8 +80,8 @@ class ExtrudeCircleShape(Shape):
     def create_solid(self):
         """Creates a extruded 3d solid using points with circular edges.
 
-           Returns:
-              A CadQuery solid: A 3D solid volume
+        Returns:
+           A CadQuery solid: A 3D solid volume
         """
 
         # so a positive offset moves extrusion further from axis of azimuthal
@@ -98,9 +102,7 @@ class ExtrudeCircleShape(Shape):
 
         self.wire = wire
 
-        solid = wire.extrude(
-            distance=extrusion_distance,
-            both=self.extrude_both)
+        solid = wire.extrude(distance=extrusion_distance, both=self.extrude_both)
 
         solid = self.rotate_solid(solid)
         cutting_wedge = calculate_wedge_cut(self)
