@@ -1,4 +1,3 @@
-
 from typing import Optional, Tuple
 
 from paramak import Shape
@@ -15,16 +14,20 @@ class RotateMixedShape(Shape):
 
     def __init__(
         self,
-        rotation_angle: Optional[float] = 360.,
-        color: Optional[Tuple[float, float, float, Optional[float]]] = (0.121, 0.47, 0.705),
+        rotation_angle: float = 360.0,
+        color: Tuple[float, float, float, Optional[float]] = (
+            0.121,
+            0.47,
+            0.705,
+        ),
+        name: str = "rotatemixedshape",
         **kwargs
     ):
 
-        super().__init__(
-            color=color,
-            **kwargs
-        )
+        super().__init__(color=color, name=name, **kwargs)
         self.rotation_angle = rotation_angle
+        self.color = color
+        self.name = name
 
     @property
     def rotation_angle(self):
