@@ -1,4 +1,3 @@
-
 from typing import Optional, Tuple
 
 from paramak import RotateMixedShape
@@ -15,8 +14,13 @@ class RotateStraightShape(RotateMixedShape):
 
     def __init__(
         self,
-        rotation_angle: Optional[float] = 360.,
-        color: Optional[Tuple[float, float, float, Optional[float]]] = (0.89, 0.101, 0.109),
+        rotation_angle: float = 360.0,
+        color: Tuple[float, float, float, Optional[float]] = (
+            0.89,
+            0.101,
+            0.109,
+        ),
+        name: str = "rotatestraightshape",
         **kwargs
     ):
 
@@ -24,5 +28,6 @@ class RotateStraightShape(RotateMixedShape):
             rotation_angle=rotation_angle,
             color=color,
             connection_type="straight",
+            name=name,
             **kwargs
         )
