@@ -1,7 +1,7 @@
-
-from typing import Optional, List, Tuple
+from typing import List, Optional, Tuple
 
 from cadquery import Workplane
+
 from paramak import Shape
 
 
@@ -27,23 +27,27 @@ class SweepCircleShape(Shape):
         self,
         radius: float,
         path_points: List[Tuple[float, float]],
-        workplane: Optional[str] = "XY",
-        path_workplane: Optional[str] = "XZ",
-        force_cross_section: Optional[bool] = False,
-        color: Optional[Tuple[float, float, float, Optional[float]]] = (0.651, 0.808, 0.89),
+        workplane: str = "XY",
+        path_workplane: str = "XZ",
+        force_cross_section: bool = False,
+        color: Tuple[float, float, float, Optional[float]] = (
+            0.651,
+            0.808,
+            0.89,
+        ),
+        name: str = "sweepcircleshape",
         **kwargs
     ):
 
-        super().__init__(
-            workplane=workplane,
-            color=color,
-            **kwargs
-        )
+        super().__init__(workplane=workplane, color=color, name=name, **kwargs)
 
         self.radius = radius
         self.path_points = path_points
+        self.workplane = workplane
         self.path_workplane = path_workplane
         self.force_cross_section = force_cross_section
+        self.color = color
+        self.name = name
 
     @property
     def radius(self):
@@ -73,9 +77,7 @@ class SweepCircleShape(Shape):
                 "workplane and path_workplane must start with the same letter"
             )
         elif value == self.workplane:
-            raise ValueError(
-                "workplane and path_workplane must be different"
-            )
+            raise ValueError("workplane and path_workplane must be different")
         else:
             self._path_workplane = value
 
@@ -104,18 +106,16 @@ class SweepCircleShape(Shape):
 
                 wires.append(wire)
 
-                wire = (
-                    wire.center(-point[0], 0)
-                    .workplane(offset=-point[1] * factor)
-                )
+                wire = wire.center(-point[0], 0).workplane(offset=-point[1] * factor)
 
             self.wire = wires
 
-            solid = wire.workplane(
-                offset=self.path_points[-1][1] * factor) \
-                .center(self.path_points[-1][0], 0) \
-                .circle(self.radius) \
+            solid = (
+                wire.workplane(offset=self.path_points[-1][1] * factor)
+                .center(self.path_points[-1][0], 0)
+                .circle(self.radius)
                 .sweep(path, multisection=True)
+            )
 
         else:
 
