@@ -1,11 +1,11 @@
-
 import os
 import sys
-from pathlib import Path
 import time
+from pathlib import Path
+
 from notebook_testing import notebook_run
 
-sys.path.append(os.path.join(os.path.dirname(__file__), '..', 'examples'))
+sys.path.append(os.path.join(os.path.dirname(__file__), "..", "examples"))
 
 
 def main():
