@@ -1,18 +1,17 @@
-
 import math
 import unittest
 
-import paramak
 import pytest
 
+import paramak
+
 
 class TestPoloidalFieldCoilSet(unittest.TestCase):
-
     def setUp(self):
         self.test_shape = paramak.PoloidalFieldCoilSet(
             heights=[10, 15, 5],
             widths=[20, 25, 30],
-            center_points=[(100, 100), (200, 200), (300, 300)]
+            center_points=[(100, 100), (200, 200), (300, 300)],
         )
 
     def test_default_parameters(self):
@@ -45,19 +44,19 @@ class TestPoloidalFieldCoilSet(unittest.TestCase):
         given."""
 
         assert self.test_shape.processed_points == [
-            (110.0, 105.0, 'straight'),
-            (110.0, 95.0, 'straight'),
-            (90.0, 95.0, 'straight'),
-            (90.0, 105.0, 'straight'),
-            (212.5, 207.5, 'straight'),
-            (212.5, 192.5, 'straight'),
-            (187.5, 192.5, 'straight'),
-            (187.5, 207.5, 'straight'),
-            (315.0, 302.5, 'straight'),
-            (315.0, 297.5, 'straight'),
-            (285.0, 297.5, 'straight'),
-            (285.0, 302.5, 'straight'),
-            (110.0, 105.0, 'straight')
+            (110.0, 105.0, "straight"),
+            (110.0, 95.0, "straight"),
+            (90.0, 95.0, "straight"),
+            (90.0, 105.0, "straight"),
+            (212.5, 207.5, "straight"),
+            (212.5, 192.5, "straight"),
+            (187.5, 192.5, "straight"),
+            (187.5, 207.5, "straight"),
+            (315.0, 302.5, "straight"),
+            (315.0, 297.5, "straight"),
+            (285.0, 297.5, "straight"),
+            (285.0, 302.5, "straight"),
+            (110.0, 105.0, "straight"),
         ]
 
     def test_creation(self):
@@ -71,8 +70,13 @@ class TestPoloidalFieldCoilSet(unittest.TestCase):
         """Creates a set of pf coils using the PoloidalFieldCoilSet parametric
         component and checks that the volume is correct."""
 
-        assert self.test_shape.volume() == (pytest.approx((10 * 20 * math.pi * (2 * 100)) + (
-            15 * 25 * math.pi * (2 * 200)) + (5 * 30 * math.pi * (2 * 300))))
+        assert self.test_shape.volume() == (
+            pytest.approx(
+                (10 * 20 * math.pi * (2 * 100))
+                + (15 * 25 * math.pi * (2 * 200))
+                + (5 * 30 * math.pi * (2 * 300))
+            )
+        )
 
     def test_absolute_areas(self):
         """Creates a set of pf coils using the PoloidalFieldCoilSet parametric
@@ -80,24 +84,19 @@ class TestPoloidalFieldCoilSet(unittest.TestCase):
 
         assert len(self.test_shape.areas) == 12
         assert len(set(round(i) for i in self.test_shape.areas)) == 9
-        assert self.test_shape.areas.count(
-            pytest.approx(20 * math.pi * (2 * 100))) == 2
-        assert self.test_shape.areas.count(
-            pytest.approx(25 * math.pi * (2 * 200))) == 2
-        assert self.test_shape.areas.count(
-            pytest.approx(30 * math.pi * (2 * 300))) == 2
-        assert self.test_shape.areas.count(
-            pytest.approx(10 * math.pi * (2 * 90))) == 1
-        assert self.test_shape.areas.count(
-            pytest.approx(10 * math.pi * (2 * 110))) == 1
-        assert self.test_shape.areas.count(
-            pytest.approx(15 * math.pi * (2 * 187.5))) == 1
-        assert self.test_shape.areas.count(
-            pytest.approx(15 * math.pi * (2 * 212.5))) == 1
-        assert self.test_shape.areas.count(
-            pytest.approx(5 * math.pi * (2 * 285))) == 1
-        assert self.test_shape.areas.count(
-            pytest.approx(5 * math.pi * (2 * 315))) == 1
+        assert self.test_shape.areas.count(pytest.approx(20 * math.pi * (2 * 100))) == 2
+        assert self.test_shape.areas.count(pytest.approx(25 * math.pi * (2 * 200))) == 2
+        assert self.test_shape.areas.count(pytest.approx(30 * math.pi * (2 * 300))) == 2
+        assert self.test_shape.areas.count(pytest.approx(10 * math.pi * (2 * 90))) == 1
+        assert self.test_shape.areas.count(pytest.approx(10 * math.pi * (2 * 110))) == 1
+        assert (
+            self.test_shape.areas.count(pytest.approx(15 * math.pi * (2 * 187.5))) == 1
+        )
+        assert (
+            self.test_shape.areas.count(pytest.approx(15 * math.pi * (2 * 212.5))) == 1
+        )
+        assert self.test_shape.areas.count(pytest.approx(5 * math.pi * (2 * 285))) == 1
+        assert self.test_shape.areas.count(pytest.approx(5 * math.pi * (2 * 315))) == 1
 
     def test_PoloidalFieldCoilSet_incorrect_height(self):
         """Checks that an error is raised when a PoloidalFieldCoilSet is made
@@ -107,12 +106,10 @@ class TestPoloidalFieldCoilSet(unittest.TestCase):
             paramak.PoloidalFieldCoilSet(
                 heights=10,
                 widths=[20, 20, 20],
-                center_points=[(100, 100), (200, 200), (300, 300)])
+                center_points=[(100, 100), (200, 200), (300, 300)],
+            )
 
-        self.assertRaises(
-            ValueError,
-            make_PoloidalFieldCoilSet_incorrect_height
-        )
+        self.assertRaises(ValueError, make_PoloidalFieldCoilSet_incorrect_height)
 
     def test_PoloidalFieldCoilSet_incorrect_width(self):
         """Checks that an error is raised when a PoloidalFieldCoilSet is made
@@ -122,12 +119,10 @@ class TestPoloidalFieldCoilSet(unittest.TestCase):
             paramak.PoloidalFieldCoilSet(
                 heights=[10, 10, 10],
                 widths=20,
-                center_points=[(100, 100), (200, 200), (300, 300)])
+                center_points=[(100, 100), (200, 200), (300, 300)],
+            )
 
-        self.assertRaises(
-            ValueError,
-            make_PoloidalFieldCoilSet_incorrect_width
-        )
+        self.assertRaises(ValueError, make_PoloidalFieldCoilSet_incorrect_width)
 
     def test_PoloidalFieldCoilSet_incorrect_center_points(self):
         """Checks that an error is raised when a PoloidalFieldCoilSet is made
@@ -135,14 +130,10 @@ class TestPoloidalFieldCoilSet(unittest.TestCase):
 
         def make_PoloidalFieldCoilSet_incorrect_center_points():
             paramak.PoloidalFieldCoilSet(
-                heights=[10, 10, 10],
-                widths=[20, 20, 20],
-                center_points=100)
+                heights=[10, 10, 10], widths=[20, 20, 20], center_points=100
+            )
 
-        self.assertRaises(
-            ValueError,
-            make_PoloidalFieldCoilSet_incorrect_center_points
-        )
+        self.assertRaises(ValueError, make_PoloidalFieldCoilSet_incorrect_center_points)
 
     def test_PoloidalFieldCoilSet_incorrect_width_length(self):
         """Checks that an error is raised when a PoloidalFieldCoilSet is made
@@ -152,9 +143,7 @@ class TestPoloidalFieldCoilSet(unittest.TestCase):
             paramak.PoloidalFieldCoilSet(
                 heights=[10, 10, 10],
                 widths=[20, 20],
-                center_points=[(100, 100), (200, 200), (300, 300)])
+                center_points=[(100, 100), (200, 200), (300, 300)],
+            )
 
-        self.assertRaises(
-            ValueError,
-            make_PoloidalFieldCoilSet_incorrect_width_length
-        )
+        self.assertRaises(ValueError, make_PoloidalFieldCoilSet_incorrect_width_length)
