@@ -1,21 +1,18 @@
-
 import unittest
+
 import pytest
+
 import paramak
 
 
 class TestVacuumVessel(unittest.TestCase):
-
     def setUp(self):
         self.cutter = paramak.PortCutterRectangular(
             width=100,
             height=100,
             distance=1100,
-            azimuth_placement_angle=[
-                0,
-                90,
-                180,
-                270])
+            azimuth_placement_angle=[0, 90, 180, 270],
+        )
         self.test_shape = paramak.VacuumVesselInnerLeg(
             inner_height=1100,
             inner_radius=700,
@@ -27,7 +24,7 @@ class TestVacuumVessel(unittest.TestCase):
             inner_radius=700,
             inner_leg_radius=100,
             thickness=100,
-            cut=self.cutter
+            cut=self.cutter,
         )
 
     def test_creation(self):
