@@ -1,15 +1,14 @@
-
 import os
 import unittest
 from pathlib import Path
 
 import pytest
 from cadquery import Plane
+
 from paramak import ExtrudeStraightShape
 
 
 class TestExtrudeStraightShape(unittest.TestCase):
-
     def setUp(self):
         self.test_shape = ExtrudeStraightShape(
             points=[(10, 10), (10, 30), (30, 30), (30, 10)], distance=30
@@ -25,8 +24,9 @@ class TestExtrudeStraightShape(unittest.TestCase):
 
         test_shape_2 = ExtrudeStraightShape(
             workplane=workplane,
-            rotation_axis='X',
-            points=[(10, 10), (10, 30), (30, 30), (30, 10)], distance=30
+            rotation_axis="X",
+            points=[(10, 10), (10, 30), (30, 30), (30, 10)],
+            distance=30,
         )
 
         assert isinstance(test_shape_2.workplane, Plane)
@@ -50,9 +50,7 @@ class TestExtrudeStraightShape(unittest.TestCase):
         """Creates an ExtrudeStraightShape and checks that the volume is
         correct."""
 
-        assert self.test_shape.area == pytest.approx(
-            (20 * 20 * 2) + (20 * 30 * 4)
-        )
+        assert self.test_shape.area == pytest.approx((20 * 20 * 2) + (20 * 30 * 4))
         assert len(self.test_shape.areas) == 6
         assert self.test_shape.areas.count(pytest.approx(20 * 20)) == 2
         assert self.test_shape.areas.count(pytest.approx(20 * 30)) == 4
@@ -71,21 +69,21 @@ class TestExtrudeStraightShape(unittest.TestCase):
         out and checks that the volume is correct."""
 
         shape_with_cut = ExtrudeStraightShape(
-            points=[(0, 0), (0, 40), (40, 40), (40, 0)], distance=40,
-            cut=self.test_shape
+            points=[(0, 0), (0, 40), (40, 40), (40, 0)],
+            distance=40,
+            cut=self.test_shape,
         )
 
-        assert shape_with_cut.volume() == pytest.approx(
-            (40 * 40 * 40) - (20 * 20 * 30)
-        )
+        assert shape_with_cut.volume() == pytest.approx((40 * 40 * 40) - (20 * 20 * 30))
 
     def test_union_volume(self):
         """Creates a union of two ExtrudeStraightShapes and checks that the
         volume is correct."""
 
         unioned_shape = ExtrudeStraightShape(
-            points=[(0, 10), (0, 30), (20, 30), (20, 10)], distance=30,
-            union=self.test_shape
+            points=[(0, 10), (0, 30), (20, 30), (20, 10)],
+            distance=30,
+            union=self.test_shape,
         )
         assert unioned_shape.volume() == pytest.approx(30 * 20 * 30)
 
@@ -94,8 +92,9 @@ class TestExtrudeStraightShape(unittest.TestCase):
         intersected and checks that the volume is correct."""
 
         intersected_shape = ExtrudeStraightShape(
-            points=[(0, 10), (0, 30), (20, 30), (20, 10)], distance=30,
-            intersect=self.test_shape
+            points=[(0, 10), (0, 30), (20, 30), (20, 10)],
+            distance=30,
+            intersect=self.test_shape,
         )
         assert intersected_shape.volume() == pytest.approx(10 * 20 * 30)
 
@@ -107,8 +106,7 @@ class TestExtrudeStraightShape(unittest.TestCase):
         self.rotation_axis = "Y"
         test_volume = self.test_shape.volume()
         self.test_shape.rotation_angle = 180
-        assert self.test_shape.volume() == pytest.approx(
-            test_volume * 0.5, rel=0.01)
+        assert self.test_shape.volume() == pytest.approx(test_volume * 0.5, rel=0.01)
 
     def test_extrude_both(self):
         """Creates an ExtrudeStraightShape with extrude_both = True and False
@@ -116,8 +114,7 @@ class TestExtrudeStraightShape(unittest.TestCase):
 
         test_volume_extrude_both = self.test_shape.volume()
         self.test_shape.extrude_both = False
-        assert self.test_shape.volume() == pytest.approx(
-            test_volume_extrude_both)
+        assert self.test_shape.volume() == pytest.approx(test_volume_extrude_both)
 
     def test_export_stp(self):
         """Exports and stp file with mode = solid and wire and checks that the
@@ -125,18 +122,22 @@ class TestExtrudeStraightShape(unittest.TestCase):
 
         os.system("rm test_solid.stp test_solid2.stp test_wire.stp")
 
-        self.test_shape.export_stp('test_solid.stp', mode='solid')
-        self.test_shape.export_stp('test_solid2.stp')
-        self.test_shape.export_stp('test_wire.stp', mode='wire')
+        self.test_shape.export_stp("test_solid.stp", mode="solid")
+        self.test_shape.export_stp("test_solid2.stp")
+        self.test_shape.export_stp("test_wire.stp", mode="wire")
 
         assert Path("test_solid.stp").exists() is True
         assert Path("test_solid2.stp").exists() is True
         assert Path("test_wire.stp").exists() is True
 
-        assert Path("test_solid.stp").stat().st_size == \
-            Path("test_solid2.stp").stat().st_size
-        assert Path("test_wire.stp").stat().st_size < \
-            Path("test_solid2.stp").stat().st_size
+        assert (
+            Path("test_solid.stp").stat().st_size
+            == Path("test_solid2.stp").stat().st_size
+        )
+        assert (
+            Path("test_wire.stp").stat().st_size
+            < Path("test_solid2.stp").stat().st_size
+        )
 
         os.system("rm test_solid.stp test_solid2.stp test_wire.stp")
 
@@ -146,16 +147,13 @@ class TestExtrudeStraightShape(unittest.TestCase):
 
         def incorrect_points_definition():
             self.test_shape.points = [
-                (10, 10, 'straight'),
-                (10, 30, 'straight'),
-                (30, 30, 'straight'),
-                (30, 10, 'straight')
+                (10, 10, "straight"),
+                (10, 30, "straight"),
+                (30, 30, "straight"),
+                (30, 10, "straight"),
             ]
 
-        self.assertRaises(
-            ValueError,
-            incorrect_points_definition
-        )
+        self.assertRaises(ValueError, incorrect_points_definition)
 
     def test_export_html_with_different_workplanes(self):
         """Checks that all the workplanes produce an html file when using the
@@ -166,8 +164,8 @@ class TestExtrudeStraightShape(unittest.TestCase):
             self.test_shape.workplane = workplane
             fig = self.test_shape.export_html(workplane + ".html")
             assert Path(workplane + ".html").exists() is True
-            assert fig.layout.xaxis.title['text'] == workplane[0]
-            assert fig.layout.yaxis.title['text'] == workplane[1]
+            assert fig.layout.xaxis.title["text"] == workplane[0]
+            assert fig.layout.yaxis.title["text"] == workplane[1]
 
 
 if __name__ == "__main__":
